@@ -2,7 +2,7 @@
                           imagemapeditor.cpp  -  description
                             -------------------
     begin                : Wed Apr 4 2001
-    copyright            : (C) 2001 by Jan SchÃÂ¯ÃÂ¿ÃÂ½er
+    copyright            : (C) 2001 by Jan Schäfer
     email                : j_schaef@informatik.uni-kl.de
 ***************************************************************************/
 
@@ -18,74 +18,81 @@
 #include <iostream>
 #include <assert.h>
 
-// QT
-#include <QScrollArea>
-
+// Qt
+#include <QApplication>
+#include <QAction>
+#include <QDialogButtonBox>
 #include <qlayout.h>
-#include <QListWidget>
 #include <qpushbutton.h>
-#include <qpixmap.h>
 #include <qcombobox.h>
-#include <qsplitter.h>
-#include <qfileinfo.h>
-#include <qtextstream.h>
-#include <QMenu>
-#include <qtooltip.h>
-#include <qpainter.h>
-#include <qtabwidget.h>
 #include <qfontdatabase.h>
 #include <qfile.h>
+#include <QFileDialog>
+#include <qfileinfo.h>
+#include <QIcon>
+#include <QInputDialog>
 #include <QLinkedList>
+#include <QListWidget>
+#include <QMenu>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <qpixmap.h>
+#include <qpainter.h>
+#include <QPushButton>
+#include <QScrollArea>
+#include <qsplitter.h>
+#include <QStandardPaths>
+#include <qtabwidget.h>
+#include <QTextEdit>
+#include <qtextstream.h>
+#include <qtooltip.h>
+#include <QUndoStack>
+#include <QVBoxLayout>
 
-// KDE
-#include <kundostack.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kaction.h>
+// KDE Frameworks
+#include "kimagemapeditor_debug.h"
+#include <klocalizedstring.h>
 #include <kstandardaction.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
 #include <kmessagebox.h>
-#include <kapplication.h>
 #include <kedittoolbar.h>
 #include <kactioncollection.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <kstatusbar.h>
 #include <kxmlguifactory.h>
 #include <kio/job.h>
-#include <kinputdialog.h>
 #include <ktoggleaction.h>
 #include <krecentfilesaction.h>
 #include <kxmlguiwindow.h>
+#include <KGenericFactory>
+#include <KSharedConfig>
+#include <KUndoActions>
+#include <KConfigGroup>
+
 // local
 #include "kimagemapeditor.h"
 #include "kimagemapeditor.moc"
 #include "drawzone.h"
 #include "kimedialogs.h"
 #include "kimecommands.h"
-#include <kicon.h>
 #include "areacreator.h"
 #include "arealistview.h"
 #include "imageslistview.h"
 #include "mapslistview.h"
 #include "kimecommon.h"
 #include "imagemapchoosedialog.h"
+#include "version.h"
 
-#include <QTextEdit>
-
-#include <kparts/genericfactory.h>
-#include <kcomponentdata.h>
-
-// Factory code for KDE 3
-typedef KParts::GenericFactory<KImageMapEditor> KimeFactory;
+typedef KGenericFactory<KImageMapEditor> KimeFactory;
 K_EXPORT_COMPONENT_FACTORY( libkimagemapeditor , KimeFactory )
 
 KImageMapEditor::KImageMapEditor(QWidget *parentWidget,
             QObject *parent, const QStringList & )
   : KParts::ReadWritePart(parent)
 {
-  setComponentData( KimeFactory::componentData() );
+  KAboutData aboutData( "kimagemapeditor", i18n("KImageMapEditor"),
+              KIMAGEMAPEDITOR_VERSION, i18n( "An HTML imagemap editor" ),
+              KAboutLicense::GPL,
+              i18n("(c) 2001-2003 Jan Sch&auml;fer <email>janschaefer@users.sourceforge.net</email>"));
+  setComponentData(aboutData, false);
 
 //  KDockMainWindow* mainWidget;
 
@@ -94,7 +101,7 @@ KImageMapEditor::KImageMapEditor(QWidget *parentWidget,
   tabWidget = 0L;
 
   if (mainWindow) {
-//    kDebug() << "KImageMapEditor: We got a KDockMainWindow !";
+//    qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor: We got a KDockMainWindow !";
 
 //    K3DockWidget* parentDock = mainDock->getMainDockWidget();
     areaDock = new QDockWidget(i18n("Areas"),mainWindow);
@@ -249,17 +256,6 @@ void KImageMapEditor::init()
   setImageActionsEnabled(false);
 }
 
-KAboutData* KImageMapEditor::createAboutData()
-{
-    KAboutData* aboutData =
-              new KAboutData( "kimagemapeditor", 0, ki18n("KImageMapEditor"),
-              "1.0", ki18n( "An HTML imagemap editor" ),
-              KAboutData::License_GPL,
-              ki18n("(c) 2001-2003 Jan Sch&auml;fer <email>janschaefer@users.sourceforge.net</email>"));
-    return aboutData;
-}
-
-
 void KImageMapEditor::setReadWrite(bool)
 {
 
@@ -337,8 +333,11 @@ void KImageMapEditor::setModified(bool modified)
 
 KConfig *KImageMapEditor::config()
 {
+    /* TODO KF5
     KSharedConfigPtr tmp = KimeFactory::componentData().config();
     return tmp.data();
+    */
+    return new KConfig();
 }
 
 void KImageMapEditor::readConfig(const KConfigGroup &config) {
@@ -407,9 +406,9 @@ void KImageMapEditor::openLastURL(const KConfigGroup & config) {
   QString lastImage = config.readPathEntry("lastactiveimage", QString());
 
 
-//  kDebug() << "loading from group : " << config.group();
+//  qCDebug(KIMAGEMAPEDITOR_LOG) << "loading from group : " << config.group();
 
-//  kDebug() << "loading entry lastopenurl : " << lastURL.path();
+//  qCDebug(KIMAGEMAPEDITOR_LOG) << "loading entry lastopenurl : " << lastURL.path();
 //  KMessageBox::information(0L, config.group()+" "+lastURL.path());
   if (!lastURL.isEmpty()) {
     openUrl(lastURL);
@@ -417,7 +416,7 @@ void KImageMapEditor::openLastURL(const KConfigGroup & config) {
       mapsListView->selectMap(lastMap);
     if (!lastImage.isEmpty())
       setPicture(lastImage);
-//    kDebug() << "opening HTML file with map " << lastMap << " and image " << lastImage;
+//    qCDebug(KIMAGEMAPEDITOR_LOG) << "opening HTML file with map " << lastMap << " and image " << lastImage;
 //    if (! openHTMLFile(lastURL, lastMap, lastImage) )
 //      closeUrl();
       //openUrl(lastURL);
@@ -427,13 +426,13 @@ void KImageMapEditor::openLastURL(const KConfigGroup & config) {
 }
 
 void KImageMapEditor::saveLastURL(KConfigGroup & config) {
-  kDebug() << "saveLastURL: " << url().path();
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "saveLastURL: " << url().path();
   config.writePathEntry("lastopenurl",url().path());
   config.writeEntry("lastactivemap",mapName());
   config.writePathEntry("lastactiveimage",_imageUrl.path());
-//  kDebug() << "writing entry lastopenurl : " << url().path();
-//  kDebug() << "writing entry lastactivemap : " << mapName();
-//  kDebug() << "writing entry lastactiveimage : " << _imageUrl.path();
+//  qCDebug(KIMAGEMAPEDITOR_LOG) << "writing entry lastopenurl : " << url().path();
+//  qCDebug(KIMAGEMAPEDITOR_LOG) << "writing entry lastactivemap : " << mapName();
+//  qCDebug(KIMAGEMAPEDITOR_LOG) << "writing entry lastactiveimage : " << _imageUrl.path();
   //KMessageBox::information(0L, QString("Group: %1 Saving ... %2").arg(config.group()).arg(url().path()));
 }
 
@@ -447,7 +446,7 @@ void KImageMapEditor::setupActions()
   temp->setToolTip(i18n("Open new picture or HTML file"));
 
   // File Open Recent
-  recentFilesAction = KStandardAction::openRecent(this, SLOT(openURL(const KUrl&)),
+  recentFilesAction = KStandardAction::openRecent(this, SLOT(openURL(const QUrl&)),
                                       actionCollection());
 	// File Save
   temp =KStandardAction::save(this, SLOT(fileSave()), actionCollection());
@@ -483,22 +482,22 @@ void KImageMapEditor::setupActions()
 
 
   // Edit Delete
-  deleteAction = new KAction(KIcon("edit-delete"),
+  deleteAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
       i18n("&Delete"), this);
   actionCollection()->addAction("edit_delete", deleteAction );
   connect(deleteAction, SIGNAL(triggered(bool) ), SLOT (slotDelete()));
-  deleteAction->setShortcut(QKeySequence(Qt::Key_Delete));
+  actionCollection()->setDefaultShortcut(deleteAction, QKeySequence(Qt::Key_Delete));
   deleteAction->setWhatsThis(i18n("<h3>Delete</h3>"
                           "Click this to <em>delete</em> the selected area."));
   deleteAction->setEnabled(false);
 
   // Edit Undo/Redo
-  _commandHistory = new KUndoStack(this);
-  _commandHistory->createUndoAction(actionCollection());
-  _commandHistory->createRedoAction(actionCollection());
+  _commandHistory = new QUndoStack(this);
+  KUndoActions::createUndoAction(_commandHistory, actionCollection());
+  KUndoActions::createRedoAction(_commandHistory, actionCollection());
 
   // Edit Properties
-    areaPropertiesAction  = new KAction(i18n("Pr&operties"), this);
+    areaPropertiesAction  = new QAction(i18n("Pr&operties"), this);
     actionCollection()->addAction("edit_properties", areaPropertiesAction );
   connect(areaPropertiesAction, SIGNAL(triggered(bool)), SLOT(showTagEditor()));
   areaPropertiesAction->setEnabled(false);
@@ -538,26 +537,26 @@ void KImageMapEditor::setupActions()
   showAltAction->setText(i18n("Show Alt Tag"));
   connect(showAltAction, SIGNAL(toggled(bool)),this, SLOT (slotShowAltTag(bool)));
 
-    mapNameAction  = new KAction(i18n("Map &Name..."), this);
+    mapNameAction  = new QAction(i18n("Map &Name..."), this);
     actionCollection()->addAction("map_name", mapNameAction );
   connect(mapNameAction, SIGNAL(triggered(bool)), SLOT(mapEditName()));
 
-    mapNewAction  = new KAction(i18n("Ne&w Map..."), this);
+    mapNewAction  = new QAction(i18n("Ne&w Map..."), this);
     actionCollection()->addAction("map_new", mapNewAction );
   connect(mapNewAction, SIGNAL(triggered(bool)), SLOT(mapNew()));
   mapNewAction->setToolTip(i18n("Create a new map"));
 
-    mapDeleteAction  = new KAction(i18n("D&elete Map"), this);
+    mapDeleteAction  = new QAction(i18n("D&elete Map"), this);
     actionCollection()->addAction("map_delete", mapDeleteAction );
   connect(mapDeleteAction, SIGNAL(triggered(bool)), SLOT(mapDelete()));
   mapDeleteAction->setToolTip(i18n("Delete the current active map"));
 
-    mapDefaultAreaAction  = new KAction(i18n("Edit &Default Area..."), this);
+    mapDefaultAreaAction  = new QAction(i18n("Edit &Default Area..."), this);
     actionCollection()->addAction("map_defaultarea", mapDefaultAreaAction );
   connect(mapDefaultAreaAction, SIGNAL(triggered(bool)), SLOT(mapDefaultArea()));
   mapDefaultAreaAction->setToolTip(i18n("Edit the default area of the current active map"));
 
-    temp  = new KAction(i18n("&Preview"), this);
+    temp  = new QAction(i18n("&Preview"), this);
     actionCollection()->addAction("map_preview", temp );
   connect(temp, SIGNAL(triggered(bool)), SLOT(mapPreview()));
   temp->setToolTip(i18n("Show a preview"));
@@ -565,30 +564,30 @@ void KImageMapEditor::setupActions()
   // IMAGE
   i18n("&Image");
 
-  imageAddAction  = new KAction(i18n("Add Image..."), this);
+  imageAddAction  = new QAction(i18n("Add Image..."), this);
   actionCollection()->addAction("image_add", imageAddAction );
   connect(imageAddAction, SIGNAL(triggered(bool)), SLOT(imageAdd()));
   imageAddAction->setToolTip(i18n("Add a new image"));
 
-    imageRemoveAction  = new KAction(i18n("Remove Image"), this);
+    imageRemoveAction  = new QAction(i18n("Remove Image"), this);
     actionCollection()->addAction("image_remove", imageRemoveAction );
   connect(imageRemoveAction, SIGNAL(triggered(bool)), SLOT(imageRemove()));
   imageRemoveAction->setToolTip(i18n("Remove the current visible image"));
 
-    imageUsemapAction  = new KAction(i18n("Edit Usemap..."), this);
+    imageUsemapAction  = new QAction(i18n("Edit Usemap..."), this);
     actionCollection()->addAction("image_usemap", imageUsemapAction );
   connect(imageUsemapAction, SIGNAL(triggered(bool)), SLOT(imageUsemap()));
   imageUsemapAction->setToolTip(i18n("Edit the usemap tag of the current visible image"));
 
-    temp  = new KAction(i18n("Show &HTML"), this);
+    temp  = new QAction(i18n("Show &HTML"), this);
     actionCollection()->addAction("map_showhtml", temp );
   connect(temp, SIGNAL(triggered(bool)), SLOT(mapShowHTML()));
 
 
   QActionGroup *drawingGroup = new QActionGroup(this);
   // Selection Tool
-  arrowAction = new KToggleAction(KIcon("arrow"), i18n("&Selection"), this);
-  arrowAction->setShortcut(QKeySequence("s"));
+  arrowAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("arrow")), i18n("&Selection"), this);
+  actionCollection()->setDefaultShortcut(arrowAction, QKeySequence("s"));
   actionCollection()->addAction("tool_arrow", arrowAction);
   connect(arrowAction, SIGNAL(triggered(bool)), SLOT (slotDrawArrow()));
   arrowAction->setWhatsThis(i18n("<h3>Selection</h3>"
@@ -597,8 +596,8 @@ void KImageMapEditor::setupActions()
   arrowAction->setChecked(true);
 
   // Circle
-  circleAction = new KToggleAction(KIcon( "circle"), i18n("&Circle"), this);
-  circleAction->setShortcut(QKeySequence("c"));
+  circleAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("circle")), i18n("&Circle"), this);
+  actionCollection()->setDefaultShortcut(circleAction, QKeySequence("c"));
 
   actionCollection()->addAction("tool_circle", circleAction);
   connect(circleAction, SIGNAL(triggered(bool)), this, SLOT(slotDrawCircle()));
@@ -607,8 +606,8 @@ void KImageMapEditor::setupActions()
   drawingGroup->addAction(circleAction);
 
   // Rectangle
-    rectangleAction = new KToggleAction(KIcon("rectangle"), i18n("&Rectangle"), this);
-  rectangleAction->setShortcut(QKeySequence("r"));
+    rectangleAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("rectangle")), i18n("&Rectangle"), this);
+  actionCollection()->setDefaultShortcut(rectangleAction, QKeySequence("r"));
     actionCollection()->addAction("tool_rectangle", rectangleAction);
   connect(rectangleAction, SIGNAL(triggered(bool)), this, SLOT(slotDrawRectangle()));
   rectangleAction->setWhatsThis(i18n("<h3>Rectangle</h3>"
@@ -616,8 +615,8 @@ void KImageMapEditor::setupActions()
   drawingGroup->addAction(rectangleAction);
 
   // Polygon
-    polygonAction = new KToggleAction(KIcon("polygon"), i18n("&Polygon"), this);
-  polygonAction->setShortcut(QKeySequence("p"));
+    polygonAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("polygon")), i18n("&Polygon"), this);
+  actionCollection()->setDefaultShortcut(polygonAction, QKeySequence("p"));
     actionCollection()->addAction("tool_polygon", polygonAction);
   connect(polygonAction, SIGNAL(triggered(bool)), SLOT(slotDrawPolygon()));
   polygonAction->setWhatsThis(i18n("<h3>Polygon</h3>"
@@ -625,8 +624,8 @@ void KImageMapEditor::setupActions()
   drawingGroup->addAction(polygonAction);
 
   // Freehand
-    freehandAction = new KToggleAction(KIcon("freehand"), i18n("&Freehand Polygon"), this);
-  freehandAction->setShortcut(QKeySequence("f"));
+    freehandAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("freehand")), i18n("&Freehand Polygon"), this);
+  actionCollection()->setDefaultShortcut(freehandAction, QKeySequence("f"));
     actionCollection()->addAction("tool_freehand", freehandAction);
   connect(freehandAction, SIGNAL(triggered(bool)), SLOT(slotDrawFreehand()));
   freehandAction->setWhatsThis(i18n("<h3>Freehandpolygon</h3>"
@@ -634,8 +633,8 @@ void KImageMapEditor::setupActions()
   drawingGroup->addAction(freehandAction);
 
   // Add Point
-    addPointAction = new KToggleAction(KIcon("addpoint"), i18n("&Add Point"), this);
-  addPointAction->setShortcut(QKeySequence("a"));
+    addPointAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("addpoint")), i18n("&Add Point"), this);
+  actionCollection()->setDefaultShortcut(addPointAction, QKeySequence("a"));
     actionCollection()->addAction("tool_addpoint", addPointAction);
   connect(addPointAction, SIGNAL(triggered(bool)), SLOT(slotDrawAddPoint()));
   addPointAction->setWhatsThis(i18n("<h3>Add Point</h3>"
@@ -643,8 +642,8 @@ void KImageMapEditor::setupActions()
   drawingGroup->addAction(addPointAction);
 
   // Remove Point
-  removePointAction = new KToggleAction(KIcon("removepoint"), i18n("&Remove Point"), this);
-  removePointAction->setShortcut(QKeySequence("e"));
+  removePointAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("removepoint")), i18n("&Remove Point"), this);
+  actionCollection()->setDefaultShortcut(removePointAction, QKeySequence("e"));
   actionCollection()->addAction("tool_removepoint", removePointAction);
   connect(removePointAction, SIGNAL(triggered(bool)), 
           SLOT(slotDrawRemovePoint()));
@@ -652,64 +651,64 @@ void KImageMapEditor::setupActions()
                           "Click this to remove points from a polygon."));
   drawingGroup->addAction(removePointAction);
 
-    KAction *action  = new KAction(i18n("Cancel Drawing"), this);
+    QAction *action  = new QAction(i18n("Cancel Drawing"), this);
     actionCollection()->addAction("canceldrawing", action );
   connect(action, SIGNAL(triggered(bool)), SLOT( slotCancelDrawing() ));
-  action->setShortcut(QKeySequence(Qt::Key_Escape));
+  actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::Key_Escape));
 
-  moveLeftAction  = new KAction(i18n("Move Left"), this);
+  moveLeftAction  = new QAction(i18n("Move Left"), this);
   actionCollection()->addAction("moveleft", moveLeftAction );
   connect(moveLeftAction, SIGNAL(triggered(bool)),
          SLOT( slotMoveLeft() ));
-  moveLeftAction->setShortcut(KShortcut(QKeySequence(Qt::Key_Left)));
+  actionCollection()->setDefaultShortcut(moveLeftAction, QKeySequence(Qt::Key_Left));
 
-    moveRightAction  = new KAction(i18n("Move Right"), this);
+    moveRightAction  = new QAction(i18n("Move Right"), this);
     actionCollection()->addAction("moveright", moveRightAction );
   connect(moveRightAction, SIGNAL(triggered(bool)), SLOT( slotMoveRight() ));
-  moveRightAction->setShortcut(QKeySequence(Qt::Key_Right));
+  actionCollection()->setDefaultShortcut(moveRightAction, QKeySequence(Qt::Key_Right));
 
-    moveUpAction  = new KAction(i18n("Move Up"), this);
+    moveUpAction  = new QAction(i18n("Move Up"), this);
     actionCollection()->addAction("moveup", moveUpAction );
   connect(moveUpAction, SIGNAL(triggered(bool)), SLOT( slotMoveUp() ));
-  moveUpAction->setShortcut(QKeySequence(Qt::Key_Up));
+  actionCollection()->setDefaultShortcut(moveUpAction, QKeySequence(Qt::Key_Up));
 
-    moveDownAction  = new KAction(i18n("Move Down"), this);
+    moveDownAction  = new QAction(i18n("Move Down"), this);
     actionCollection()->addAction("movedown", moveDownAction );
   connect(moveDownAction, SIGNAL(triggered(bool)), SLOT( slotMoveDown() ));
-  moveDownAction->setShortcut(QKeySequence(Qt::Key_Down));
+  actionCollection()->setDefaultShortcut(moveDownAction, QKeySequence(Qt::Key_Down));
 
-    increaseWidthAction  = new KAction(i18n("Increase Width"), this);
+    increaseWidthAction  = new QAction(i18n("Increase Width"), this);
     actionCollection()->addAction("increasewidth", increaseWidthAction );
   connect(increaseWidthAction, SIGNAL(triggered(bool)), SLOT( slotIncreaseWidth() ));
-  increaseWidthAction->setShortcut(QKeySequence(Qt::Key_Right + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(increaseWidthAction, QKeySequence(Qt::Key_Right + Qt::SHIFT));
 
-    decreaseWidthAction  = new KAction(i18n("Decrease Width"), this);
+    decreaseWidthAction  = new QAction(i18n("Decrease Width"), this);
     actionCollection()->addAction("decreasewidth", decreaseWidthAction );
   connect(decreaseWidthAction, SIGNAL(triggered(bool)), SLOT( slotDecreaseWidth() ));
-  decreaseWidthAction->setShortcut(QKeySequence(Qt::Key_Left + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(decreaseWidthAction, QKeySequence(Qt::Key_Left + Qt::SHIFT));
 
-    increaseHeightAction  = new KAction(i18n("Increase Height"), this);
+    increaseHeightAction  = new QAction(i18n("Increase Height"), this);
     actionCollection()->addAction("increaseheight", increaseHeightAction );
   connect(increaseHeightAction, SIGNAL(triggered(bool)), SLOT( slotIncreaseHeight() ));
-  increaseHeightAction->setShortcut(QKeySequence(Qt::Key_Up + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(increaseHeightAction, QKeySequence(Qt::Key_Up + Qt::SHIFT));
 
-    decreaseHeightAction  = new KAction(i18n("Decrease Height"), this);
+    decreaseHeightAction  = new QAction(i18n("Decrease Height"), this);
     actionCollection()->addAction("decreaseheight", decreaseHeightAction );
   connect(decreaseHeightAction, SIGNAL(triggered(bool)), SLOT( slotDecreaseHeight() ));
-  decreaseHeightAction->setShortcut(QKeySequence(Qt::Key_Down + Qt::SHIFT));
+  actionCollection()->setDefaultShortcut(decreaseHeightAction, QKeySequence(Qt::Key_Down + Qt::SHIFT));
 
-    toFrontAction  = new KAction(i18n("Bring to Front"), this);
+    toFrontAction  = new QAction(i18n("Bring to Front"), this);
     actionCollection()->addAction("tofront", toFrontAction );
   connect(toFrontAction, SIGNAL(triggered(bool)), SLOT( slotToFront() ));
 
-    toBackAction  = new KAction(i18n("Send to Back"), this);
+    toBackAction  = new QAction(i18n("Send to Back"), this);
     actionCollection()->addAction("toback", toBackAction );
   connect(toBackAction, SIGNAL(triggered(bool)), SLOT( slotToBack() ));
 
-    forwardOneAction  = new KAction(KIcon("raise"), i18n("Bring Forward One"), this);
+    forwardOneAction  = new QAction(QIcon::fromTheme(QStringLiteral("raise")), i18n("Bring Forward One"), this);
     actionCollection()->addAction("forwardone", forwardOneAction );
   connect(forwardOneAction, SIGNAL(triggered(bool) ), SLOT( slotForwardOne() ));
-    backOneAction  = new KAction(KIcon("lower"), i18n("Send Back One"), this);
+    backOneAction  = new QAction(QIcon::fromTheme(QStringLiteral("lower")), i18n("Send Back One"), this);
     actionCollection()->addAction("backone", backOneAction );
   connect(backOneAction, SIGNAL(triggered(bool) ), SLOT( slotBackOne() ));
 
@@ -719,11 +718,11 @@ void KImageMapEditor::setupActions()
   connect( areaListView->upBtn, SIGNAL(pressed()), forwardOneAction, SLOT(trigger()));
   connect( areaListView->downBtn, SIGNAL(pressed()), backOneAction, SLOT(trigger()));
 
-    action  = new KAction(KIcon("configure"), i18n("Configure KImageMapEditor..."), this);
+    action  = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure KImageMapEditor..."), this);
     actionCollection()->addAction("configure_kimagemapeditor", action );
   connect(action, SIGNAL(triggered(bool) ), SLOT(slotShowPreferences()));
 
-  kDebug() << "KImageMapEditor: 1";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor: 1";
 
   if (areaDock) {
 
@@ -741,9 +740,9 @@ void KImageMapEditor::setupActions()
     actionCollection()->addAction("configure_show_imagelist", a );
   }
 
-  kDebug() << "KImageMapEditor: 2";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor: 2";
   updateActionAccess();
-  kDebug() << "KImageMapEditor: 3";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor: 3";
 }
 
 void KImageMapEditor::setupStatusBar()
@@ -769,7 +768,7 @@ void KImageMapEditor::showPopupMenu(const QPoint & pos, const QString & name)
   QMenu* pop = static_cast<QMenu *>(factory()->container(name, this));
 
   if (!pop) {
-      kWarning() << QString("KImageMapEditorPart: Missing XML definition for %1\n").arg(name);
+      qCWarning(KIMAGEMAPEDITOR_LOG) << QString("KImageMapEditorPart: Missing XML definition for %1\n").arg(name);
       return;
   }
 
@@ -783,7 +782,7 @@ void KImageMapEditor::slotShowMainPopupMenu(const QPoint & pos)
 
 void KImageMapEditor::slotShowMapPopupMenu(const QPoint & pos)
 {
-  kDebug() << "slotShowMapPopupMenu";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "slotShowMapPopupMenu";
   QTreeWidgetItem* item = mapsListView->listView()->itemAt(pos);
 
   if (isReadWrite()) {
@@ -800,7 +799,7 @@ void KImageMapEditor::slotShowMapPopupMenu(const QPoint & pos)
 
 void KImageMapEditor::slotShowImagePopupMenu(const QPoint & pos)
 {
-  kDebug() << "slotShowImagePopupMenu";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "slotShowImagePopupMenu";
   QTreeWidgetItem* item = imagesListView->itemAt(pos);
 
   imageRemoveAction->setEnabled(item);
@@ -847,7 +846,7 @@ void KImageMapEditor::slotUpdateSelectionCoords() {
     selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ", r.left(), r.top(), r.width(), r.height());
 
 //		  ,STATUS_SELECTION);
-    kapp->processEvents();
+    qApp->processEvents();
   } else
     selectionStatusText = i18n(" Selection: - ");
     //statusBar()->changeItem(" Selection : - ",STATUS_SELECTION);
@@ -859,15 +858,9 @@ void KImageMapEditor::slotUpdateSelectionCoords( const QRect & r )
 {
   selectionStatusText = i18n(" Selection: x: %1, y: %2, w: %3, h: %4 ", r.left(), r.top(), r.width(), r.height());
   updateStatusBar();
-  kapp->processEvents();
+  qApp->processEvents();
 }
 
-KApplication* KImageMapEditor::app() const
-{
-  return kapp;
-}
-
-
 void KImageMapEditor::drawToCenter(QPainter* p, const QString & str, int y, int width) {
   int xmid = width / 2;
 
@@ -886,7 +879,7 @@ QImage KImageMapEditor::getBackgroundImage() {
 
 //  QString filename = QString("dropimage_")+KGlobal::locale()->language()+".png";
 //  QString path = QString(); //KGlobal::dirs()->findResourceDir( "data", "kimagemapeditor/"+filename ) + "kimagemapeditor/"+filename;
-//  kDebug() << "getBackgroundPic : loaded image : " << path;
+//  qCDebug(KIMAGEMAPEDITOR_LOG) << "getBackgroundPic : loaded image : " << path;
 
 //  if ( ! QFileInfo(path).exists() ) {
     int width = 400;
@@ -968,13 +961,13 @@ QImage KImageMapEditor::getBackgroundImage() {
     }
 
 
-    path = KGlobal::dirs()->saveLocation( "data", "kimagemapeditor/" ) +filename;
-    kDebug() << "getBackgroundPic : save new image to : " << path;
+    path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kimagemapeditor/" ) +filename;
+    qCDebug(KIMAGEMAPEDITOR_LOG) << "getBackgroundPic : save new image to : " << path;
     pix.save(path,"PNG",100);
   }
 
   if ( ! QFileInfo(path).exists() ) {
-      kError() << "Couldn't find needed " << filename << " file in "
+      qCCritical(KIMAGEMAPEDITOR_LOG) << "Couldn't find needed " << filename << " file in "
                    "the data directory of KImageMapEditor.\n"
                    "Perhaps you have forgotten to do a make install !" << endl;
       exit(1);
@@ -1105,7 +1098,7 @@ void KImageMapEditor::deleteAllAreas()
 
 void KImageMapEditor::updateAllAreas()
 {
-//  kDebug() << "KImageMapEditor::updateAllAreas";
+//  qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::updateAllAreas";
   Area* a;
   foreach(a,*areas) {
     a->listViewItem()->setIcon(1,QIcon(makeListViewPix(*a)));
@@ -1239,7 +1232,7 @@ void KImageMapEditor::updateActionAccess()
 
   if ( 0 < selected()->count())
   {
-    kDebug() << "actions enabled";
+    qCDebug(KIMAGEMAPEDITOR_LOG) << "actions enabled";
     areaPropertiesAction->setEnabled(true);
     deleteAction->setEnabled(true);
     copyAction->setEnabled(true);
@@ -1286,7 +1279,7 @@ void KImageMapEditor::updateActionAccess()
   }
   else
   {
-    kDebug() << "Actions disabled";
+    qCDebug(KIMAGEMAPEDITOR_LOG) << "Actions disabled";
     areaPropertiesAction->setEnabled(false);
     deleteAction->setEnabled(false);
     copyAction->setEnabled(false);
@@ -1453,10 +1446,10 @@ void KImageMapEditor::setPicture(const KUrl & url) {
          imageUsemapAction->setEnabled(true);
      }
      else
-         kError() << QString("The image %1 could not be opened.").arg(url.path()) << endl;
+         qCCritical(KIMAGEMAPEDITOR_LOG) << QString("The image %1 could not be opened.").arg(url.path()) << endl;
   }
   else
-     kError() << QString("The image %1 does not exist.").arg(url.path()) << endl;
+     qCCritical(KIMAGEMAPEDITOR_LOG) << QString("The image %1 does not exist.").arg(url.path()) << endl;
 }
 
 void KImageMapEditor::setPicture(const QImage & pix) {
@@ -1472,19 +1465,19 @@ void KImageMapEditor::slotDrawArrow() {
 
 void KImageMapEditor::slotDrawCircle() {
   _currentToolType=KImageMapEditor::Circle;
-  kDebug() << "slotDrawCircle";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "slotDrawCircle";
 
 }
 
 void KImageMapEditor::slotDrawRectangle() {
   _currentToolType=KImageMapEditor::Rectangle;
-  kDebug() << "slotDrawRectangle";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "slotDrawRectangle";
 
 }
 
 void KImageMapEditor::slotDrawPolygon() {
   _currentToolType=KImageMapEditor::Polygon;
-  kDebug() << "slotDrawPolygon";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "slotDrawPolygon";
 }
 
 void KImageMapEditor::slotDrawFreehand() {
@@ -1556,10 +1549,10 @@ void KImageMapEditor::mapDefaultArea()
 void KImageMapEditor::mapEditName()
 {
   bool ok=false;
-  QString input = KInputDialog::getText(i18n("Enter Map Name"),
-    i18n("Enter the name of the map:"),
-    _mapName,&ok,widget());
-  if (ok) {
+  QString input = QInputDialog::getText(widget(),
+    i18n("Enter Map Name"), i18n("Enter the name of the map:"),
+    QLineEdit::Normal, _mapName, &ok);
+  if (ok && !input.isEmpty()) {
     if (input != _mapName) {
         if (mapsListView->nameAlreadyExists(input))
             KMessageBox::sorry(this->widget(), i18n("The name <em>%1</em> already exists.", input));
@@ -1572,19 +1565,27 @@ void KImageMapEditor::mapEditName()
 
 void KImageMapEditor::mapShowHTML()
 {
-  KDialog *dialog= new KDialog(widget());
+  QDialog *dialog = new QDialog(widget());
   dialog->setModal(true);
-  dialog->setCaption(i18n("HTML Code of Map"));
-  dialog->setButtons(KDialog::Ok);
-  dialog->setDefaultButton(KDialog::Ok);
-  QTextEdit *edit = new QTextEdit(dialog);
+  dialog->setWindowTitle(i18n("HTML Code of Map"));
+  QVBoxLayout *mainLayout = new QVBoxLayout(dialog);
+
+  QTextEdit *edit = new QTextEdit;
 
   edit->setPlainText(getHtmlCode());
   edit->setReadOnly(true);
   edit->setLineWrapMode(QTextEdit::NoWrap);
-  dialog->setMainWidget(edit);
+  mainLayout->addWidget(edit);
 //  dialog->resize(dialog->calculateSize(edit->maxLineWidth(),edit->numLines()*));
 //	dialog->adjustSize();
+
+  QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+  QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+  okButton->setDefault(true);
+  okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+  connect(buttonBox, SIGNAL(accepted()), dialog, SLOT(accept()));
+  mainLayout->addWidget(buttonBox);
+
   dialog->resize(600,400);
   dialog->exec();
   delete dialog;
@@ -1592,17 +1593,17 @@ void KImageMapEditor::mapShowHTML()
 
 void KImageMapEditor::openFile(const KUrl & url) {
   if ( ! url.isEmpty()) {
-    QString ext=QFileInfo(url.path()).completeSuffix().toLower();
-
-    if (ext=="png" || ext=="jpg" || ext=="jpeg" || ext=="gif" ||
-        ext=="bmp" || ext=="xbm" || ext=="xpm" || ext=="mng" || ext=="pnm")
+    QMimeDatabase db;
+    QMimeType openedFileType = db.mimeTypeForUrl(url);
+    if (openedFileType.name().left(6) == "image/") {
         addImage(url);
-    else
+    } else {
         openURL(url);
+    }
   }
 }
 
-bool KImageMapEditor::openURL(const KUrl & url) {
+bool KImageMapEditor::openURL(const QUrl & url) {
     // If a local file does not exist
     // we start with an empty file, so
     // that we can return true here.
@@ -1616,12 +1617,9 @@ bool KImageMapEditor::openURL(const KUrl & url) {
 
 void KImageMapEditor::fileOpen() {
 
-  QString fileName = KFileDialog::getOpenFileName(KUrl(),
-          i18n("*.png *.jpg *.jpeg *.gif *.htm *.html|Web File\n"
-          "*.png *.jpg *.jpeg *.gif *.bmp *.xbm *.xpm *.pnm *.mng|Images\n"
-          "*.htm *.html|HTML Files\n"
-          "*.png|PNG Images\n*.jpg *.jpeg|JPEG Images\n*.gif|GIF-Images\n*|All Files"),
-          widget(),i18n("Choose File to Open"));
+  QString fileName = QFileDialog::getOpenFileName(widget(), i18n("Choose File to Open"), QString(),
+                     i18n("Web File (*.png *.jpg *.jpeg *.gif *.htm *.html);;Images (*.png *.jpg *.jpeg *.gif *.bmp *.xbm *.xpm *.pnm *.mng);;"
+                          "HTML Files (*.htm *.html);;All Files (*)"));
 
   openFile(KUrl( fileName ));
 }
@@ -1658,8 +1656,7 @@ void KImageMapEditor::fileSave()
 
 void KImageMapEditor::fileSaveAs() {
 
-  KUrl url = KFileDialog::getSaveUrl(KUrl(),"*.htm *.html|" + i18n( "HTML File" ) +
-                                     "\n*.txt|" + i18n( "Text File" ) + "\n*|" + i18n( "All Files" ),widget());
+  KUrl url = QFileDialog::getSaveFileUrl(widget(), QString(), QUrl(), i18n("HTML File (*.htm *.html);;Text File (*.txt);;All Files (*)" ));
   if (url.isEmpty() || !url.isValid()) {
     return;
   }
@@ -1924,7 +1921,7 @@ bool KImageMapEditor::openHTMLFile(const KUrl & url)
         if (tagName == "map") {
           map = new MapTag();
           map->name = attr->value("name");
-	  kDebug() << "KImageMapEditor::openHTMLFile: found map with name:" << map->name;
+	  qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::openHTMLFile: found map with name:" << map->name;
 	  
           readMap=true;
         } else
@@ -2014,9 +2011,9 @@ bool KImageMapEditor::openHTMLFile(const KUrl & url)
     /*    if (maps.count() >1 || (imageUrl.isEmpty() && images.count() > 1))
     {
       ImageMapChooseDialog dialog(widget(),maps,images,url);
-      kDebug() << "KImageMapEditor::openHTMLFile: before dialog->exec()";
+      qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::openHTMLFile: before dialog->exec()";
       dialog.exec();
-      kDebug() << "KImageMapEditor::openHTMLFile: after dialog->exec()";
+      qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::openHTMLFile: after dialog->exec()";
       map = dialog.currentMap;
       imageUrl = dialog.pixUrl;
       }*/
@@ -2112,7 +2109,7 @@ void KImageMapEditor::addMap(const QString & name = QString()) {
      _htmlContent.append(new HtmlElement("\n"));
 
      _htmlContent.append(el);
-     kDebug() << "KImageMapEditor::addMap : No <body found ! Appending new map to the end.";
+     qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::addMap : No <body found ! Appending new map to the end.";
   }
 
   mapsListView->addMap(name);
@@ -2134,7 +2131,7 @@ HtmlMapElement* KImageMapEditor::findHtmlMapElement(const QString & mapName) {
     }
   }
 
-  kWarning() << "KImageMapEditor::findHtmlMapElement: couldn't find map '" << mapName << "'";
+  qCWarning(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::findHtmlMapElement: couldn't find map '" << mapName << "'";
   return 0L;
 }
 
@@ -2144,7 +2141,7 @@ HtmlMapElement* KImageMapEditor::findHtmlMapElement(const QString & mapName) {
 void KImageMapEditor::setMap(const QString & mapName) {
     HtmlMapElement* el = findHtmlMapElement(mapName);
     if (!el) {
-      kWarning() << "KImageMapEditor::setMap : Couldn't set map '" << mapName << "', because it wasn't found !";
+      qCWarning(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::setMap : Couldn't set map '" << mapName << "', because it wasn't found !";
       return;
     }
 
@@ -2230,7 +2227,7 @@ void KImageMapEditor::setMap(HtmlMapElement* mapElement) {
   deleteAllAreas();
   delete defaultArea;
   defaultArea = 0L;
-//    kDebug() << "KImageMapEditor::setMap : Setting new map : " << map->name;
+//    qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::setMap : Setting new map : " << map->name;
     _mapName = map->name;
     AreaTag tag;
 
@@ -2579,7 +2576,7 @@ void KImageMapEditor::slotMoveDown()
 
 void KImageMapEditor::slotMoveLeft()
 {
-  kDebug() << "slotMoveLeft";
+  qCDebug(KIMAGEMAPEDITOR_LOG) << "slotMoveLeft";
   QRect r=selected()->rect();
   selected()->setMoving(true);
   selected()->moveBy(-1,0);
@@ -2724,7 +2721,7 @@ void KImageMapEditor::mapDelete()
 }
 
 void KImageMapEditor::mapPreview() {
-  HTMLPreviewDialog dialog(widget(), url(), getHtmlCode());
+  HTMLPreviewDialog dialog(widget(), getHtmlCode());
   dialog.exec();
 }
 
@@ -2794,7 +2791,7 @@ void KImageMapEditor::addImage(const KUrl & imgUrl) {
     if (imgUrl.isEmpty())
         return;
 
-    QString relativePath ( toRelative(imgUrl, KUrl( url().directory() )).path() );
+    QString relativePath ( toRelative(imgUrl, KUrl( url().adjusted(QUrl::RemoveFilename).path() )).path() );
 
     QString imgHtml = QString("<img src=\"")+relativePath+QString("\">");
     ImageTag* imgTag = new ImageTag();
@@ -2833,7 +2830,8 @@ void KImageMapEditor::setImageActionsEnabled(bool b) {
 
 
 void KImageMapEditor::imageAdd() {
-    KUrl imgUrl = KFileDialog::getImageOpenUrl();
+    KUrl imgUrl = QFileDialog::getOpenFileUrl(widget(), i18n("Select image"),
+                  QUrl(), i18n("Images (*.png *.jpg *.jpeg *.gif *.bmp *.xbm *.xpm *.pnm *.mng);;All Files (*)"));
     addImage(imgUrl);
 }
 
@@ -2879,9 +2877,9 @@ void KImageMapEditor::imageUsemap() {
   }
 
   QString input =
-    KInputDialog::getItem(i18n("Enter Usemap"),
+    QInputDialog::getItem(widget(), i18n("Enter Usemap"),
 			  i18n("Enter the usemap value:"),
-			  maps,index,true,&ok,widget());
+			  maps, index, true, &ok);
   if (ok) {
      imageTag->insert("usemap", input);
      imagesListView->updateImage(imageTag);
